@@ -10,16 +10,17 @@ def verify_ml_dataset(dataset):
     TOO_MANY_ZEROES_THRESHOLD = 0.1
     FEATURE_IMPORTANCE_THRESHOLD = 0.01
 
-    checks = {"null_values": "",
-              "too_many_zeroes": "",
-              "label": "",
-              "outliers": "",
-              "data_imbalance": "",
-              "data_format": "",
-              "low_importance_features": "",
-              "data_normalization": "",
-              "string_features": ""
-              }
+    checks = {
+        "null_values": "",
+        "too_many_zeroes": "",
+        "label": "",
+        "outliers": "",
+        "data_imbalance": "",
+        "data_format": "",
+        "low_importance_features": "",
+        "data_normalization": "",
+        "string_features": "",
+    }
     Y = pd.DataFrame()
 
     # check for null values in pandas dataframe
@@ -30,7 +31,7 @@ def verify_ml_dataset(dataset):
 
     # check for label config
     for column in dataset.columns:
-        if 'label' in column:
+        if "label" in column:
             Y[column] = dataset[column]
             dataset.drop(column, axis=1, inplace=True)
     if Y.empty:
@@ -49,11 +50,11 @@ def verify_ml_dataset(dataset):
     for column_name in dataset.columns:
         column = dataset[column_name]
         count += (column == 0).sum()
-        if count > len(dataset)*TOO_MANY_ZEROES_THRESHOLD:
+        if count > len(dataset) * TOO_MANY_ZEROES_THRESHOLD:
             checks["too_many_zeroes"] = "warning"
 
     # Check for outliers
-    if checks['string_features'] == "ok":
+    if checks["string_features"] == "ok":
         z_scores = stats.zscore(dataset)
         abs_z_scores = np.abs(z_scores)
         # Select data points with a z-scores above or below 3
@@ -64,26 +65,32 @@ def verify_ml_dataset(dataset):
             checks["outliers"] = "ok"
 
     # Check for data imbalance
-    if checks['label'] == 'ok':
+    if checks["label"] == "ok":
         try:
             values = Y.value_counts()
-            if values[0]*DATA_IMBALANCE_THRESHOLD > values[1] or values[1]*DATA_IMBALANCE_THRESHOLD > values[0]:
+            if (
+                values[0] * DATA_IMBALANCE_THRESHOLD > values[1]
+                or values[1] * DATA_IMBALANCE_THRESHOLD > values[0]
+            ):
                 checks["data_imbalance"] = "warning"
             else:
                 checks["data_imbalance"] = "ok"
         except:
             labels = []
             for column_name in Y.columns:
-                if 'label' in column_name:
+                if "label" in column_name:
                     labels.append(dataset[column_name][1])
             labels.sort()
-            if labels[0]*DATA_IMBALANCE_THRESHOLD > labels[-1] or labels[-1]*DATA_IMBALANCE_THRESHOLD > labels[0]:
+            if (
+                labels[0] * DATA_IMBALANCE_THRESHOLD > labels[-1]
+                or labels[-1] * DATA_IMBALANCE_THRESHOLD > labels[0]
+            ):
                 checks["data_imbalance"] = "warning"
             else:
                 checks["data_imbalance"] = "ok"
 
     # check for feature importance
-    if checks['string_features'] == "ok":
+    if checks["string_features"] == "ok":
         xgb = XGBRegressor()
         xgb.fit(dataset, Y)
         importance = xgb.feature_importances_
@@ -95,7 +102,7 @@ def verify_ml_dataset(dataset):
             checks["low_importance_features"] = "ok"
 
     # Data normalization
-    if checks['string_features'] == "ok":
+    if checks["string_features"] == "ok":
         for val in dataset.min():
             if val < -1:
                 checks["data_normalization"] = "warning"
